@@ -19,7 +19,10 @@
 ## MassSpectrum
 setMethod(f="detectPeaks",
           signature=signature(object="MassSpectrum"),
-          definition=function(object, halfWindowSize=20, fun, SNR=2, ...) {
+          definition=function(object, halfWindowSize=20L,
+                              method=c("MAD", "SuperSmoother"), SNR=2L,
+                              fun, ## deprecated
+                              ...) {
 
   ## empty spectrum?
   if (.isEmptyWarning(object)) {
@@ -29,31 +32,33 @@ setMethod(f="detectPeaks",
 
   ## try to use user-defined noise estimation function
   if (!missing(fun)) {
+    .deprecatedArgument("1.7.12", old="fun", new="method", help="detectPeaks")
     fun <- match.fun(fun)
     noise <- fun(object@mass, object@intensity, ...)
+
+    ## wrong noise argument given?
+    isCorrectNoise <- is.matrix(noise) &&
+                      (nrow(noise) == length(object) && ncol(noise) == 2)
+
+    if (!isCorrectNoise) {
+      stop("The noise argument is not valid.")
+    }
   } else {
-    noise <- estimateNoise(object, ...)
-  }
-
-  ## wrong noise argument given?
-  isCorrectNoise <- is.matrix(noise) &&
-                    (nrow(noise) == length(object) && ncol(noise) == 2)
-
-  if (!isCorrectNoise) {
-    stop("The noise argument is not valid.")
+    ## estimate noise
+    noise <- estimateNoise(object, method=method, ...)
   }
 
   ## find local maxima
   localMaxima <- .findLocalMaximaLogical(object, halfWindowSize=halfWindowSize)
 
   ## include only local maxima which are above the noise
-  aboveNoise <- object@intensity > (SNR * noise[, 2])
+  aboveNoise <- object@intensity > (SNR * noise[, 2L])
 
   isPeak <- aboveNoise & localMaxima
 
   return(createMassPeaks(mass=object@mass[isPeak],
                          intensity=object@intensity[isPeak],
-                         snr=object@intensity[isPeak]/noise[isPeak, 2],
+                         snr=object@intensity[isPeak]/noise[isPeak, 2L],
                          metaData=object@metaData))
 })
 
