@@ -1,4 +1,4 @@
-## Copyright 2011-2012 Sebastian Gibb
+## Copyright 2011-2013 Sebastian Gibb
 ## <mail@sebastiangibb.de>
 ##
 ## This file is part of MALDIquant for R and related languages.
@@ -16,14 +16,14 @@
 ## You should have received a copy of the GNU General Public License
 ## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
 
-isMassObject <- function(x) {
-    return(inherits(x=x, what="AbstractMassObject"));
+.isMassObject <- function(x) {
+  return(inherits(x=x, what="AbstractMassObject"))
 }
 
 isMassSpectrum <- function(x) {
-    return(is(object=x, class2="MassSpectrum"));
+  return(is(object=x, class2="MassSpectrum"))
 }
 
 isMassPeaks <- function(x) {
-    return(is(object=x, class2="MassPeaks"));
+  return(is(object=x, class2="MassPeaks"))
 }
