@@ -22,17 +22,17 @@ setMethod(f="plot",
           definition=function(x, col="black", xlab="mass", ylab="intensity",
                               type=ifelse(isMassPeaks(x), "h", "l"),
                               xlim=c(ifelse(length(x@mass),
-                                            min(x@mass, na.rm=TRUE), 0),
+                                            min(x@mass, na.rm=TRUE), 0L),
                                      ifelse(length(x@mass),
-                                            max(x@mass, na.rm=TRUE), 1)),
+                                            max(x@mass, na.rm=TRUE), 1L)),
                               ylim=c(0, ifelse(length(x@intensity),
                                                max(x@intensity, na.rm=TRUE),
-                                               1)),
+                                               1L)),
                               main=x@metaData$name, sub=x@metaData$file,
                               cex.sub=0.75, col.sub="#808080",
                               abline.col="#808080", ...) {
 
-  if (all(sub == x@metaData$file) && length(x@metaData$file) > 1) {
+  if (all(sub == x@metaData$file) && length(x@metaData$file) > 1L) {
     sub <- paste0("merged ", ifelse(isMassSpectrum(x), "spectrum", "peaks"),
                   " composed of ", length(x@metaData$file), " ",
                   ifelse(isMassSpectrum(x), "MassSpectrum", "MassPeaks"),
@@ -42,6 +42,6 @@ setMethod(f="plot",
   plot(x=x@mass, y=x@intensity, col=col, type=type, xlab=xlab, ylab=ylab,
        xlim=xlim, ylim=ylim, main=main, sub=sub, cex.sub=cex.sub,
        col.sub=col.sub, ...)
-  abline(h=0, col=abline.col)
+  abline(h=0L, col=abline.col)
 })
 
