@@ -5,7 +5,7 @@
 ## warping demo
 
 
-## load necessary libraries
+## load necessary packages
 library("MALDIquant")
 
 ## load example spectra
@@ -17,16 +17,16 @@ spectra <- fiedler2009subset[seq(1, 16, by=4)]
 ## some preprocessing
 
 ## sqrt transform (for variance stabilization)
-spectra <- transformIntensity(spectra, sqrt)
+spectra <- transformIntensity(spectra, method="sqrt")
 
 ## simple 5 point moving average for smoothing spectra
-spectra <- transformIntensity(spectra, movingAverage, halfWindowSize=2)
+spectra <- smoothIntensity(spectra, method="MovingAverage", halfWindowSize=2)
 
 ## remove baseline
 spectra <- removeBaseline(spectra)
 
-## calibrate intensity values by "total ion current"
-spectra <- standardizeTotalIonCurrent(spectra)
+## calibrate intensity values by "Total Ion Current"
+spectra <- calibrateIntensity(spectra)
 
 ## run peak detection
 peaks <- detectPeaks(spectra)
@@ -50,7 +50,7 @@ par(mfrow=c(2, 2))
 plotSpectra <- function(unwarped, warped, range) {
   plot(unwarped[[1]], main=paste0("unwarped spectra (mass ",
                                   paste0(range, collapse=":"), " Da)"),
-       xlim=range, ylim=c(0, 4e-4), type="n")
+       xlim=range, ylim=c(0, 2e-3), type="n")
 
   for (i in seq(along=unwarped)) {
     lines(unwarped[[i]], col=colour[i])
@@ -58,7 +58,7 @@ plotSpectra <- function(unwarped, warped, range) {
 
   plot(unwarped[[1]], main=paste0("warped spectra (mass ",
                                  paste0(range, collapse=":"), " Da)"),
-       xlim=range, ylim=c(0, 4e-4), type="n")
+       xlim=range, ylim=c(0, 2e-3), type="n")
 
   for (i in seq(along=warped)) {
     lines(warped[[i]], col=colour[i])
